pub struct Container { /* private fields */ }Expand description
A struct that acts as a container for storing and retrieving values of different types.
pub struct Container { /* private fields */ }A struct that acts as a container for storing and retrieving values of different types.