Struct Response
Source pub struct Response<'a> {
pub result: Option<Value>,
pub error: Option<Error>,
pub id: Id<'a>,
}
Represents a JSON-RPC response.
Result of the method invocation.
Error occurred during method invocation.
Creates a successful JSON-RPC response.
Creates an error JSON-RPC response.
Formats the value using the given formatter.
Read more
Serialize this value into the given Serde serializer.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.